"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports["default"] = void 0;

var _isPromise = _interopRequireDefault(require("is-promise"));

var _select2 = _interopRequireDefault(require("ant-design-vue/es/select"));

var _types = _interopRequireDefault(require("./types"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

/**
 * @Date: 2020/11/23 9:20 下午
 * @Author: Fioanna
 * @Description: 建议下拉框
 */
var ASelectOption = _select2["default"].Option;
var _default = {
  name: 'ESuggestSelect',
  props: _types["default"],
  data: function data() {
    return {
      // 当前是否在请求数据
      isSearching: false,
      // 搜索关键词
      searchKey: '',
      // 建议搜索框列表
      suggestList: []
    };
  },
  computed: {
    // 默认值
    valueObj: function valueObj() {
      return this.labelInValue && this.value ? {
        value: this.value,
        label: this.label
      } : this.value;
    }
  },
  model: {
    prop: 'value',
    event: 'change'
  },
  methods: {
    /**
     * 输入后获取建议列表
     * @param key
     * @private
     */
    _search: function _search(key) {
      var _this = this;

      this.$data.searchKey = key;

      if (!this.$data.isSearching && key) {
        this.$data.isSearching = true;
        var result = this.$props.loadList ? this.$props.loadList(key) : this.getSuggestList(key);

        if ((0, _isPromise["default"])(result)) {
          result.then(function (list) {
            // 当前的搜索和发送协议的搜索一直的时候才修改list
            if (_this.$data.searchKey === key) {
              if (list && list.length > 0) {
                _this.$data.suggestList = list;
              }
            }
          })["catch"](function () {})["finally"](function () {
            _this.$data.isSearching = false;
          });
        }
      }
    },

    /**
     * 点击某一项选择
     * @param item
     * @private
     */
    _select: function _select(item) {
      var value = item[this.$props.valueName];

      if (this.$props.value !== value) {
        // 选中的改变才发送事件
        var label = item[this.$props.labelName];
        this.$emit('change', value, label, item);
      }
    },

    /**
     * 获取建议列表，可继承
     * @param key 输入的文字
     * @returns {Promise<*[]>}
     */
    // eslint-disable-next-line
    getSuggestList: function getSuggestList(key) {
      return Promise.resolve([]);
    },

    /**
     * 清空建议列表
     * 主要给外部调用的
     */
    resetSuggestList: function resetSuggestList() {
      this.$data.suggestList = [];
      this.$emit('change', undefined, undefined);
    }
  },
  render: function render() {
    var _this2 = this;

    var h = arguments[0];
    var _this$$props = this.$props,
        disabled = _this$$props.disabled,
        placeholder = _this$$props.placeholder,
        labelInValue = _this$$props.labelInValue,
        valueName = _this$$props.valueName,
        labelName = _this$$props.labelName;
    var contentDom = null;

    if (this.$data.searchKey) {
      // 输入了文字的就展示数据列表，或者无数据
      if (this.$data.suggestList.length > 0) {
        contentDom = this.$data.suggestList.map(function (option) {
          var value = option[valueName];
          var label = option[labelName];
          return h(ASelectOption, {
            attrs: {
              disabled: option.disabled,
              value: value,
              title: label
            },
            key: value,
            on: {
              "click": function click() {
                _this2._select(option);
              }
            }
          }, [label]);
        });
      }
    } else {
      // 未输入提示输入
      contentDom = h("span", {
        slot: "notFoundContent"
      }, [placeholder]);
    }

    return h(_select2["default"], {
      attrs: {
        showArrow: false,
        filterOption: false,
        defaultActiveFirstOption: false,
        showSearch: true,
        disabled: disabled,
        placeholder: placeholder,
        labelInValue: labelInValue,
        value: this.valueObj
      },
      on: {
        "search": this._search
      }
    }, [contentDom]);
  }
};
exports["default"] = _default;